@@ -48,6 +48,13 @@ class VariableList:
         init = Variable(initial_value, name)
         return cls(init)
 
+    @classmethod
+    def empty(cls, name):
+        i = Variable(0, name)
+        inst = cls(i)
+        inst.vars = []
+        return inst
+
     @property
     def value(self):
         return self.vals[-1]
@@ -77,6 +84,10 @@ class VariableList:
             raise ValueError("Variables must be of the same name.")
         self.vals.append(val)
 
+    def add(self, val):
+        new = Variable(val, self.name)
+        self.vars.append(new)
+
     def __len__(self):
         return len(self.vals)
 
@@ -84,7 +95,7 @@ class VariableList:
         return f"List ({self.name}): " + str(self.vals)
 
     def __lt__(self, other):
-        return self.vals[-1] < other
+        return self.value < other
 
     def __eq__(self, other):
         if not isinstance(other, VariableList):
@@ -92,7 +103,7 @@ class VariableList:
         return self.vals == other.vals
 
     def last_element_equals(self, other):
-        return self.vals[-1] == other
+        return self.value == other
 
 
 def scatter(x: VariableList, y: VariableList):
